@@ -3,14 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0500';
 
 use strict;
 use warnings;
 
 use MIDI;
-use MIDI::Event;
-use MIDI::Track;
 use MIDI::Simple;
 use Music::Tempo;
 
@@ -42,23 +40,6 @@ sub setup_score {
 }
 
 
-sub new_track {
-    my %args = (
-        channel => 0,
-        patch   => 0,
-        tempo   => 500000,
-        @_,
-    );
-
-    my $track = MIDI::Track->new;
-
-    $track->new_event( 'set_tempo', 0, $args{tempo} );
-    $track->new_event( 'patch_change', 0, $args{channel}, $args{patch} );
-
-    return $track;
-}
-
-
 sub set_chan_patch {
     my ( $score, $channel, $patch ) = @_;
 
@@ -183,7 +164,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0403
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -193,8 +174,6 @@ version 0.0403
 
   MIDI::Util::set_chan_patch( $score, 0, 1 );
 
-  my $track = MIDI::Util::new_track( channel => 0, patch => 1, tempo => 450_000 );
-
   my $dump = MIDI::Util::dump('volume');
 
   my @notes = midi_format('C','C#','Db','D'); # C, Cs, Df, D
@@ -231,25 +210,6 @@ Named parameters and defaults:
   patch:   0
   octave:  4
 
-=head2 new_track
-
-  $track = MIDI::Util::new_track;  # Use defaults
-
-  $track = MIDI::Util::new_track(  # Override defaults
-    channel => $channel,
-    patch   => $patch,
-    tempo   => $tempo,
-  );
-
-Set the B<channel>, B<patch>, and B<tempo> and return a L<MIDI::Track>
-object.
-
-Named parameters and defaults:
-
-  channel: 0
-  patch:   0
-  tempo:   500000
-
 =head2 set_chan_patch
 
   MIDI::Util::set_chan_patch( $score, $channel );  # Just set the channel
